@@ -5,7 +5,7 @@ require 'immutable-struct'
 
 RSpec.configure do |config|
   config.expect_with :rspec do |c|
-    c.syntax = [:should, :expect]
+    c.syntax = [:expect]
   end
   config.order = "random"
 end
